%global commit 9a8ab938b4024af8f0455edb54f80fdb5195968b
%global date   20141101

# python3 for Fedora only (not available at EPEL), F21+ has Java 8
%if 0%{?fedora}
 %global with_python3 1
 %if 0%{?fedora} >= 21
  %global java_version 1.8
 %else
  %global java_version 1.7
 %endif
%else
 %global java_version 1.7
%endif

Name:           py4j
Version:        0.8.3
Release:        0.1.%{date}git%(c=%{commit}; echo ${c:0:7})%{?dist}
Summary:        Py4J enables Python programs to dynamically access arbitrary Java objects

License:        BSD
URL:            https://%{name}.sf.net
Source0:        https://github.com/bartdag/%{name}/archive/%{commit}.tar.gz#/%{name}-%{commit}.tar.gz
# F22+ unbundles hamcrest from junit.jar
Patch0:         py4j-0.8.3-add-hamcrest-in-classpath.patch

BuildArch:      noarch

BuildRequires:  python2-devel python-setuptools

%if 0%{?with_python3}
BuildRequires:  python3-devel python3-setuptools
%endif

BuildRequires:  ant-junit ant-javadoc maven-local

# F22+ unbundles hamcrest from junit
%if 0%{?fedora} >= 22
BuildRequires:  hamcrest
%endif

BuildRequires:  python-nose

# FIXME sphinx seems to be optional feature
#BuildRequires:  python-sphinx

Requires:       %{name}-java = %{version}-%{release}

%description
Py4J enables Python programs running in a Python interpreter
to dynamically access Java objects in a Java Virtual Machine.
Methods are called as if the Java objects resided in the Python
interpreter and Java collections can be accessed through standard
Python collection methods.
Py4J also enables Java programs to call back Python objects.
Py4J is distributed under the BSD license.


%if 0%{?with_python3} 
%package -n python3-%{name}
Summary:        Py4J enables Python3 programs to dynamically access arbitrary Java objects
Requires:       python3
Requires:       %{name}-java = %{version}-%{release}
%endif

%if 0%{?with_python3}
%description -n python3-%{name}
Py4J enables Python programs running in a Python interpreter
to dynamically access Java objects in a Java Virtual Machine.
Methods are called as if the Java objects resided in the Python
interpreter and Java collections can be accessed through standard
Python collection methods.
Py4J also enables Java programs to call back Python objects.
Py4J is distributed under the BSD license.
This package is for usage with Python3.
%endif


%package java
Summary:        Py4J Java Library

%description java
%{summary}.

%package doc
Summary:        Documentation files for %{name}

%description doc
%{summary}.


%package javadoc
Summary:        Javadoc files for %{name}

%description javadoc
%{summary}.


%prep
%setup -qn%{name}-%{commit}
%if 0%{?fedora} >= 22
%patch0
%endif
rm -r current-release net.sf.* %{name}-java/*.jar
sed -i "s|junit-4.10.jar|$(build-classpath junit)|g" %{name}-java/ant.properties
sed -i "s|1\.6|%{java_version}|g" %{name}-java/build.xml
sed -i "s|'.*'|''|g" %{name}-python/src/%{name}/version.py
sed -i "s|version>.*<|version><|" %{name}-java/pom.xml
%mvn_file net.sf.%{name}:%{name}:%{version} %{name}-java/%{name}
# do not confuse jar folder and do not build tests by default (latter is done in check)
sed -e "s|src|%{name}-python/\0|g" -e "/, '%{name}\.tests'/d" %{name}-python/setup.py >setup-notests.py

%build
%{__python2} setup-notests.py build
%if 0%{?with_python3}
mkdir python3
pushd python3
sed 's,"%{name},"../%{name},' ../setup-notests.py >setup-python3.py
%{__python3} setup-python3.py build
popd
%endif
pushd %{name}-java
ant -Dversion='' -Djunit.path=%{junit_path} jar
ant javadoc
popd

%install
%{__python2} setup-notests.py install -O1 --skip-build --root %{buildroot}
%if 0%{?with_python3}
pushd python3
%{__python3} setup-python3.py install -O1 --skip-build --root %{buildroot}
popd
%endif
find %{buildroot} -name '*.jar' -print -delete
pushd %{name}-java
%mvn_artifact pom.xml %{name}.jar
%mvn_install -J javadoc
popd
mkdir -p %{buildroot}%{_datadir}/%{name}
ln -sf ../java/%{name}/%{name}.jar %{buildroot}%{_datadir}/%{name}

%check
# do build tests only, see above
sed -e "s|src|%{name}-python/\0|g" -e "s|'%{name}', ||" %{name}-python/setup.py >setup.py
ant -f %{name}-java/build.xml python-test
ant -Djunit.path='%{junit_path}' -f %{name}-java/build.xml java-test
# FIXME run tests also for py3?


%files
%license %{name}-python/LICENSE.txt
%doc README.rst %{name}-python/README.txt
%{python2_sitelib}/*.egg-info
%{python2_sitelib}/%{name}/

%if 0%{?with_python3}
%files -n python3-%{name}
%license %{name}-python/LICENSE.txt
%doc README.rst %{name}-python/README.txt
%{python3_sitelib}/*.egg-info
%{python3_sitelib}/%{name}/
%endif

%files doc
%license %{name}-web/LICENSE
%doc %{name}-web/*.rst %{name}-web/themes/ %{name}-web/images/

%files java -f .mfiles
%license %{name}-java/LICENSE.txt
%doc %{name}-java/README.txt %{name}-java/changelog.txt %{name}-java/TODO
# not sure, should we own the folder in main package?
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*.jar

%files javadoc -f .mfiles-javadoc
%license %{name}-java/LICENSE.txt


%changelog
* Mon Apr 27 2015 Raphael Groner <projects.rg@smart.ms> - 0.8.3-0.1.20141101git9a8ab93
- initial
